@@ -34,6 +34,10 @@ else:
     return 'Done'
 
 
+def help_():
+    print('')
+
+
 def stop():
     exit()
 
@@ -61,7 +65,8 @@ def main(things):
 
 if __name__ == '__main__':
     print('Welcome to UsefulHelper')
-    print('Seeing https://github.com/')
+    print('Seeing https://github.com/CleverCreater/UsefulHelper')
     main()
 else:
+    print(__name__)
     main()
